Class: EventTickets::EventTickets::Service
- Inherits:
-
Object
- Object
- EventTickets::EventTickets::Service
- Includes:
- GRPC::GenericService
- Defined in:
- lib/io/event_tickets/a_rpc_services_pb.rb
Overview
Manages event-ticket productions, venues, events, ticket types, tickets, validation, and redemption. Ticket types belong to a production; issued tickets are associated with an event and ticket type.